Enum ColumnKey
pub enum ColumnKey {
NotKey,
Primary,
Unique,
Multiple,
}Variants
NotKey
This column is not the first column of any key
Primary
This column is part of the primary key
Unique
This column is the first column of a unique key
Multiple
This column is the first column of a non-unique key